@@ -3,7 +3,7 @@ import shutil
 import tempfile
 from itertools import chain
 from dektools.module import get_module_attr
-from dektools.file import sure_dir, write_file, read_text, remove_path, sure_parent_dir, normal_path
+from dektools.file import sure_dir, write_file, read_text, remove_path, sure_parent_dir, normal_path, format_path_desc
 from dektools.output import pprint
 from dektools.shell import shell_output, shell_exitcode
 from dektools.net import get_available_port
@@ -35,7 +35,7 @@ def _which(x):
 
 
 def _where(x):
-    for path in chain(iter([os.getcwd()]), iter(os.environ['PATH'].split(';'))):
+    for path in chain(iter([os.getcwd()]), iter(os.environ['PATH'].split(os.pathsep))):
         fp = os.path.join(path, x)
         if os.path.exists(fp):
             return fp
@@ -62,6 +62,7 @@ default_methods = {
     'exist': lambda x: os.path.exists(x),
     'noexist': lambda x: not os.path.exists(x),
 
+    'fpd': format_path_desc,
     'pd': _parent_dir,
     'bn': os.path.basename,
     'sdir': sure_dir,
