@@ -22,25 +22,25 @@ def make_shell_properties(shell):
 
 
 package_name = __name__.partition(".")[0]
-try:
-    package_version = metadata.version(metadata.version(package_name))
-except:
-    package_version = None
+path_home = os.path.expanduser('~')
+is_on_win = os.name == "nt"
+path_root = path_home[:path_home.find(os.sep)] if is_on_win else os.sep
 
 default_properties = {
     '__meta__': {
         'name': package_name,
-        'version': package_version
+        'version': metadata.version(package_name)
     },
     'python': sys.executable,
     **make_shell_properties(current_shell),
     'pid': os.getpid(),
     'pname': os.path.basename(sys.executable),
+    'root': path_root,
+    'home': path_home,
 
-    'os_name': os.name,
-    'platform': sys.platform,
-    'os_win': os.name == "nt",
-    'home': os.path.expanduser('~'),
+    'oswin': is_on_win,
+    'ops': os.pathsep,
+    'oss': os.sep,
 
     'ser': serializer,
 
