@@ -2,7 +2,7 @@ import os
 import re
 import shlex
 import functools
-from dektools.str import deep_format
+from dektools.str import deep_format, split_table_line
 from dektools.common import classproperty
 from dektools.shell import shell_output, shell_exitcode
 from ....utils.serializer import serializer
@@ -11,6 +11,9 @@ from ....utils.cmd import cmd2ak
 
 class MarkerBase:
     tag_head = None
+    tag_head_args = None
+    tag_head_re = None
+    tag_head_re_args = None
     tag_tail = None
     branch_set = set()
 
@@ -38,13 +41,24 @@ class MarkerBase:
     trans_marker__end = "}"
     trans_marker__escape = "\\"
 
-    value_unset = object()
+    VALUE_UNSET = type('Unset', (), {})
 
     def recognize(self, command):
         command = self.strip(command)
-        return self.tag_head == '' or \
-            command.startswith(self.tag_head) and \
-            command[len(self.tag_head):len(self.tag_head) + 1] in ('', ' ')
+        if self.tag_head is not None:
+            target = self.tag_head if self.tag_head_args is None else self.tag_head % self.tag_head_args
+            if command.startswith(target):
+                return not (
+                        target and
+                        re.match('[0-9a-zA-Z_-]', target[-1]) and
+                        command[len(target):len(target) + 1] not in ' \t\f\r'
+                )
+            return False
+        elif self.tag_head_re is not None:
+            return bool(re.match(
+                self.tag_head_re if self.tag_head_re_args is None else self.tag_head_re % self.tag_head_re_args,
+                command))
+        return False
 
     def bubble_continue(self, env, marker_node_self, marker_node_target):
         return None
@@ -62,6 +76,10 @@ class MarkerBase:
     def set_var_raw(env, key, value):
         env.context[key] = value
 
+    @staticmethod
+    def remove_var(env, name):
+        env.remove_variable(name)
+
     def call_func(self, env, func_name, *args, **kwargs):
         args, kwargs = self.var_map_batch(env, *args, **kwargs)
         func = env.context.get(func_name)
@@ -69,6 +87,12 @@ class MarkerBase:
             func = self.eval(env, func_name)
         return func(*args, **kwargs)
 
+    def cmd_call(self, env, s):
+        argv = self.split(s)
+        func = argv[0]
+        args, kwargs = self.cmd2ak(argv[1:])
+        return self.call_func(env, func, *args, **kwargs)
+
     def translate(self, env, s):
         def evaluate(s, default):
             if s.startswith(self.trans_marker__ignore):
@@ -86,10 +110,10 @@ class MarkerBase:
 
         def handler(expression, marker, _):
             key = marker[len(self.trans_marker__begin):]
+            if key.startswith(self.trans_marker_command_output):
+                return shell_output(expression, env=env.environ())
             if key.startswith(self.trans_marker_command_rc):
                 return shell_exitcode(expression, env=env.environ())
-            elif key.startswith(self.trans_marker_command_output):
-                return shell_output(expression, env=env.environ())
             elif key.startswith(self.trans_marker_env_full):
                 return env.environ().get(expression.strip(), default_value)
             elif key.startswith(self.trans_marker_env):
@@ -139,13 +163,8 @@ class MarkerBase:
         return shlex.split(command, posix=posix)
 
     @staticmethod
-    def split_raw(command, maxsplit=-1):
-        result = []
-        for x in command.split(' '):
-            x = x.strip()
-            if x:
-                result.append(x)
-        return ' '.join(result).split(' ', maxsplit)
+    def split_raw(command, maxsplit=None, sep=None):
+        return split_table_line(command, maxsplit, sep)
 
     @staticmethod
     def eval(env, s, v=None):
@@ -155,17 +174,18 @@ class MarkerBase:
         try:
             return self.eval(env, s, v)
         except NameError:
-            return self.value_unset
+            return self.VALUE_UNSET
 
     @staticmethod
-    def eval_multi(env, s, v=None):
+    def eval_lines(env, s, v=None):
         locals_ = env.eval_locals | (v or {})
-        exec(s, locals_)
-        return locals_
+        globals_ = {}
+        exec(s, locals_, globals_)
+        return globals_
 
     @staticmethod
     def var_map(env, s):
-        if re.match(r'\$[0-9a-zA-Z_]+$', s):
+        if re.match(r'\$[^\W\d]\w*$', s):
             return env.eval_locals[s[1:]]
         else:
             return s.replace(r'\$', "$")
@@ -180,20 +200,38 @@ class MarkerBase:
 
 
 class EndMarker(MarkerBase):
-    tag_head = "@end"
+    tag_head = "end"
 
 
 class BreakMarker(MarkerBase):
-    tag_head = "@break"
+    tag_head = "break"
 
 
 class ContinueMarker(MarkerBase):
-    tag_head = "@continue"
+    tag_head = "continue"
 
 
 class MarkerWithEnd(MarkerBase):
     tag_tail = EndMarker
 
+    def get_inner_content(self, env, marker_node):
+        commands = []
+        marker_node.walk(lambda node, depth: commands.extend([] if depth == 0 else [node.command]))
+        text = '\n'.join(commands)
+        return self.translate(env, text)
+
+    def eval_codes(self, env, code):
+        if not code:
+            return None
+        codes = code.split('\n')
+        codes[-1] = f"_ = {codes[-1]}"
+        return self.eval_lines(env, '\n'.join(codes))['_']
+
+
+class MarkerNoTranslator(MarkerBase):
+    def translate(self, env, s):
+        return s
+
 
 class MarkerShell(MarkerBase):
     shell_cls = None
