@@ -1,8 +1,8 @@
 import re
-from .base import MarkerBase, MarkerWithEnd
+from .base import MarkerNoTranslator, MarkerWithEnd
 
 
-class MarkerCommentBase(MarkerBase):
+class MarkerCommentBase(MarkerNoTranslator):
     pass
 
 
@@ -10,8 +10,8 @@ class CommentMarker(MarkerCommentBase):
     tag_head = "#"
 
 
-class CommentBlockMarker(MarkerCommentBase, MarkerWithEnd):
-    tag_head = "@#"
+class CommentMultiLineMarker(MarkerCommentBase, MarkerWithEnd):
+    tag_head = "##"
 
     def exec(self, env, command, marker_node, marker_set):
         return []
