@@ -2,7 +2,7 @@ from .base import MarkerBase
 
 
 class DefaultMarker(MarkerBase):
-    tag_head = "@default"
+    tag_head = "default"
 
     def exec(self, env, command, marker_node, marker_set):
         args = self.split_raw(command, 2)
