@@ -2,7 +2,7 @@ from .base import MarkerBase
 
 
 class EchoMarker(MarkerBase):
-    tag_head = "@echo"
+    tag_head = "echo"
 
     def exec(self, env, command, marker_node, marker_set):
         argv = self.split_raw(command, 1)
