@@ -19,14 +19,14 @@ class MarkerEnvBase(MarkerBase):
 
 
 class EnvMarker(MarkerEnvBase):
-    tag_head = "@env"
+    tag_head = "env"
 
     def get_environ(self, env):
         return os.environ
 
 
 class EnvShellMarker(MarkerEnvBase):
-    tag_head = "@envs"
+    tag_head = "envs"
 
     def get_environ(self, env):
         return env.environ_pointer
