@@ -4,7 +4,7 @@ from .base import MarkerBase
 
 
 class GotoMarker(MarkerBase):
-    tag_head = "@goto"
+    tag_head = "goto"
 
     def exec(self, env, command, marker_node, marker_set):
         argv = self.split(command)
@@ -12,7 +12,7 @@ class GotoMarker(MarkerBase):
 
 
 class InvokeMarker(MarkerBase):
-    tag_head = "@invoke"
+    tag_head = "invoke"
 
     def exec(self, env, command, marker_node, marker_set):
         argv = self.split(command)
