@@ -4,7 +4,7 @@ from .base import MarkerWithEnd
 
 
 class PipMarker(MarkerWithEnd):
-    tag_head = "@pip"
+    tag_head = "pip"
 
     def exec(self, env, command, marker_node, marker_set):
         def walk(node, depth):
