@@ -5,7 +5,7 @@ from .base import MarkerBase
 
 
 class RedirectMarker(MarkerBase):
-    tag_head = "@redirect"
+    tag_head = "redirect"
 
     def exec(self, env, command, marker_node, marker_set):
         path_dir = self.split_raw(command, 1)[1]
@@ -16,3 +16,13 @@ class RedirectMarker(MarkerBase):
                 shrf = shell_properties['shrf']
                 shell_wrapper(f'{shrf} {env.context["fp"]}', env=env.environ())
                 self.exit()
+
+
+class ShiftMarker(MarkerBase):
+    tag_head = "shift"
+
+    def exec(self, env, command, marker_node, marker_set):
+        path_dir = self.split_raw(command, 1)[1]
+        path_shell = redirect_shell_by_path_tree(path_dir)
+        for k, v in make_shell_properties(path_shell).items():
+            self.set_var_raw(env, k, v)
