@@ -4,19 +4,20 @@ from .empty import EmptyMarker
 
 
 class ShellMarker(MarkerWithEnd):
-    tag_head = "@shell"
+    tag_head = "shell"
+    target_marker_cls = EmptyMarker
 
     def exec(self, env, command, marker_node, marker_set):
         argv = self.split_raw(command, 1)
         config = self.get_item(argv, 1, '').strip()
         if config:
-            config = eval(f'dict({config})', {'environ': os.environ})
+            config = eval(f'dict({config})', {'environ': env.environ()})
         else:
             config = None
-        marker = marker_set.find_marker_by_cls(EmptyMarker)
+        marker = marker_set.find_marker_by_cls(self.target_marker_cls)
         result = []
         for child in marker_node.children:
-            if child.is_type(EmptyMarker):
+            if child.is_type(self.target_marker_cls):
                 node = marker_set.node_cls(
                     marker,
                     child.command,
